[GRASS-SVN] r67852 - in grass/trunk/gui/wxpython: datacatalog docs gui_core lmgr

svn_grass at osgeo.org svn_grass at osgeo.org
Tue Feb 16 19:27:51 PST 2016


Author: wenzeslaus
Date: 2016-02-16 19:27:50 -0800 (Tue, 16 Feb 2016)
New Revision: 67852

Modified:
   grass/trunk/gui/wxpython/datacatalog/tree.py
   grass/trunk/gui/wxpython/docs/wxGUI.html
   grass/trunk/gui/wxpython/gui_core/preferences.py
   grass/trunk/gui/wxpython/lmgr/frame.py
Log:
wxGUI/lmgr: simplify notebook tabs names

This saves horizonatal space, so all items can
fit well on all platfroms.

GRASS-dev Layer Manager notebook
https://lists.osgeo.org/pipermail/grass-dev/2016-January/078645.html
https://lists.osgeo.org/pipermail/grass-dev/2016-February/078935.html


Modified: grass/trunk/gui/wxpython/datacatalog/tree.py
===================================================================
--- grass/trunk/gui/wxpython/docs/wxGUI.html	2016-02-17 01:13:35 UTC (rev 67851)
+++ grass/trunk/gui/wxpython/docs/wxGUI.html	2016-02-17 03:27:50 UTC (rev 67852)
@@ -569,7 +569,7 @@
 
 <dl>
   <dt>Ctrl+Tab</dt>
-  <dd>Switch 'Map layers' and 'Command output' tab</dd>
+  <dd>Switch 'Layers' and 'Console' tab</dd>
   <dt>Ctrl+Q</dt>
   <dd>Quit</dd>
 </dl>
@@ -584,7 +584,7 @@
   <dd>Close workspace</dd>
 </dl>
 
-<b>Map Layers</b>
+<b>Layers</b>
 <dl>
   <dt>Ctrl+Shift+L</dt>
   <dd>Add multiple raster or vector map layers to current map display</dd>
@@ -596,7 +596,7 @@
   <dd>Close current map display</dd>
 </dl>
 
-<b>Command line prompt</b>
+<b>Console</b>
 <dl>
   <dt>Tab</dt>
   <dd>Show command tooltips</dd>

Modified: grass/trunk/gui/wxpython/gui_core/preferences.py
===================================================================
--- grass/trunk/gui/wxpython/gui_core/preferences.py	2016-02-17 01:13:35 UTC (rev 67851)
+++ grass/trunk/gui/wxpython/gui_core/preferences.py	2016-02-17 03:27:50 UTC (rev 67852)
@@ -279,7 +279,7 @@
 
         row += 1
         hideSearch = wx.CheckBox(parent = panel, id = wx.ID_ANY,
-                                 label = _("Hide '%s' tab (requires GUI restart)") % _("Search module"),
+                                 label = _("Hide '%s' tab (requires GUI restart)") % _("Modules"),
                                  name = 'IsChecked')
         hideSearch.SetValue(self.settings.Get(group = 'manager', key = 'hideTabs', subkey = 'search'))
         self.winId['manager:hideTabs:search'] = hideSearch.GetId()
@@ -289,7 +289,7 @@
         
         row += 1
         hidePyShell = wx.CheckBox(parent = panel, id = wx.ID_ANY,
-                                  label = _("Hide '%s' tab (requires GUI restart)") % _("Python shell"),
+                                  label = _("Hide '%s' tab (requires GUI restart)") % _("Python"),
                                   name = 'IsChecked')
         hidePyShell.SetValue(self.settings.Get(group = 'manager', key = 'hideTabs', subkey = 'pyshell'))
         self.winId['manager:hideTabs:pyshell'] = hidePyShell.GetId()
@@ -302,7 +302,7 @@
         #
         row += 1
         copySelectedTextToClipboard = wx.CheckBox(parent = panel, id = wx.ID_ANY,
-                                                  label = _("Automatically copy selected text to clipboard (in Command console)"),
+                                                  label = _("Automatically copy selected text to clipboard (in the Console tab)"),
                                                   name = 'IsChecked')
         copySelectedTextToClipboard.SetValue(self.settings.Get(group = 'manager', key = 'copySelectedTextToClipboard', subkey = 'enabled'))
         self.winId['manager:copySelectedTextToClipboard:enabled'] = copySelectedTextToClipboard.GetId()

Modified: grass/trunk/gui/wxpython/lmgr/frame.py
===================================================================
--- grass/trunk/gui/wxpython/lmgr/frame.py	2016-02-17 01:13:35 UTC (rev 67851)
+++ grass/trunk/gui/wxpython/lmgr/frame.py	2016-02-17 03:27:50 UTC (rev 67852)
@@ -291,7 +291,7 @@
         self.notebookLayers.SetTabAreaColour(globalvar.FNPageColor)
         menu = self._createTabMenu()
         self.notebookLayers.SetRightClickMenu(menu)
-        self.notebook.AddPage(page = self.notebookLayers, text = _("Map layers"), name = 'layers')
+        self.notebook.AddPage(page = self.notebookLayers, text = _("Layers"), name = 'layers')
         
         # create 'command output' text area
         self._gconsole = GConsole(guiparent = self, giface = self._giface,
@@ -302,7 +302,7 @@
         self.goutput = GConsoleWindow(parent=self.notebook, gconsole=self._gconsole,
                                       menuModel=self._moduleTreeBuilder.GetModel(),
                                       gcstyle = GC_PROMPT)
-        self.notebook.AddPage(page = self.goutput, text = _("Command console"), name = 'output')
+        self.notebook.AddPage(page = self.goutput, text = _("Console"), name = 'output')
 
         self.goutput.showNotification.connect(lambda message: self.SetStatusText(message))
 
@@ -320,19 +320,19 @@
             self.search = SearchModuleWindow(parent=self.notebook, handlerObj=self,
                                              model=self._moduleTreeBuilder.GetModel())
             self.search.showNotification.connect(lambda message: self.SetStatusText(message))
-            self.notebook.AddPage(page = self.search, text = _("Search modules"), name = 'search')
+            self.notebook.AddPage(page = self.search, text = _("Modules"), name = 'search')
         else:
             self.search = None
         
         # create 'data catalog' notebook page
         self.datacatalog = DataCatalog(parent=self.notebook, giface=self._giface)
         self.datacatalog.showNotification.connect(lambda message: self.SetStatusText(message))
-        self.notebook.AddPage(page = self.datacatalog, text = _("Data catalog"), name = 'catalog')
+        self.notebook.AddPage(page = self.datacatalog, text = _("Data"), name = 'catalog')
         
         # create 'python shell' notebook page
         if not UserSettings.Get(group = 'manager', key = 'hideTabs', subkey = 'pyshell'):
             self.pyshell = PyShellWindow(parent=self.notebook, giface=self._giface)
-            self.notebook.AddPage(page = self.pyshell, text = _("Python shell"), name = 'pyshell')
+            self.notebook.AddPage(page = self.pyshell, text = _("Python"), name = 'pyshell')
         else:
             self.pyshell = None
         



More information about the grass-commit mailing list
--- grass/trunk/gui/wxpython/datacatalog/tree.py	2016-02-17 01:13:35 UTC (rev 67851)
+++ grass/trunk/gui/wxpython/datacatalog/tree.py	2016-02-17 03:27:50 UTC (rev 67852)
@@ -451,14 +451,14 @@
             label = _("Displaying {name}...").format(name=string)
             self.showNotification.emit(message=label)
             label = "d." + self.selected_type.label[:4] + " --q map=" + string + \
-                    _(" -- completed. Go to Map layers for further operations.")
+                    _(" -- completed. Go to Layers tab for further operations.")
             if self.selected_type.label == 'vector':
                 self._giface.lmgr.AddMaps(layerName, 'vector', True)
             elif self.selected_type.label == 'raster':
                 self._giface.lmgr.AddMaps(layerName, 'raster', True)
             else:
                 self._giface.lmgr.AddMaps(layerName, 'raster_3d', True)
-                label = "d.rast --q map=" + string + _(" -- completed. Go to 'Map layers' for further operations.")  # generate this message (command) automatically?
+                label = "d.rast --q map=" + string + _(" -- completed. Go to Layers tab for further operations.")  # generate this message (command) automatically?
             self.showNotification.emit(message=label)
             Debug.msg(1, "LAYER " + self.selected_layer.label + " DISPLAYED")
         else:

Modified: grass/trunk/gui/wxpython/docs/wxGUI.html
===================================================================